@@ -1,10 +1,9 @@
 package CMS::Drupal;
-$CMS::Drupal::VERSION = '0.093';
+$CMS::Drupal::VERSION = '0.094';
 # ABSTRACT: Perl interface to the Drupal CMS
 
 use strict;
 use warnings;
-use 5.010;
 
 use Moo;
 use Types::Standard    qw/ Optional Maybe Str Int slurpy Dict /;
@@ -24,13 +23,13 @@ sub dbh {
   confess "Fatal error! No dbi:driver provided! "    unless exists $args->{'driver'};
 
   my %types = (
-    database => DBName,
-    driver   => DBDriver,
-    username => DBUsername,
-    password => DBPassword,
-    host     => DBHost,
-    port     => DBPort,
-    prefix   => DBPrefix,
+    'database' => DBName,
+    'driver'   => DBDriver,
+    'username' => DBUsername,
+    'password' => DBPassword,
+    'host'     => DBHost,
+    'port'     => DBPort,
+    'prefix'   => DBPrefix,
   );
 
   for ( keys %{$args} ) {
@@ -50,33 +49,36 @@ sub dbh {
 }
 
 1; ## return true to end package CMS::Drupal
+
 __END__
 
 =pod
- 
+
+=encoding UTF-8
+
 =head1 NAME
- 
-CMS::Drupal -- Perl interface to the Drupal CMS
+
+CMS::Drupal - Perl interface to the Drupal CMS
 
 =head1 VERSION
 
-version 0.093
- 
+version 0.094
+
 =head1 SYNOPSIS
- 
- use CMS::Drupal;           
 
- my $drupal = CMS::Drupal->new();
+  use CMS::Drupal;           
 
- my $database_handle = CMS::Drupal->dbh(
-  'database' => "my_db",
-  'driver'   => "mysql",
-  'username' => "my_user",
-  'password' => "my_password",
-  'host'     => "my_host",
-  'port'     => "3306",
-  'prefix"   => "myapp_"
- );
+  my $drupal = CMS::Drupal->new();
+
+  my $database_handle = CMS::Drupal->dbh(
+    'database' => "my_db",
+    'driver'   => "mysql",
+    'username' => "my_user",
+    'password' => "my_password",
+    'host'     => "my_host",
+    'port'     => "3306",
+    'prefix"   => "myapp_"
+  );
 
 =head1 DESCRIPTION
 
@@ -91,58 +93,74 @@ You will need the appropriate DBI driver installed to connect to your
 database. The DBI will hint at what you need if you don't have it, so
 long as you set the 'driver' parameter correctly.
 
-=head1 FUNCTIONALITY
-
-As of this writing, all the author needs is a DB handle in order to use other
-CMS::Drupal::* modules. You are welcome to contribute code if you want this
-module to do anything else. For example, many CMS interfaces allow you to put
-the CMS into "maintenance mode," so you can work on the database with the
-site off-line. It would be relatively simple to add methods for tasks such as
-that.
-
-=head1 USAGE
-
-Use the module as shown in the Synopsis above.
-
 =head1 METHODS
 
+=head2 new
+
+Instantiates an object in the CMS::Drupal class.
+
 =head2 dbh
 
 Returns a database handle connected to your Drupal DB.
 
 =head3 Parameters
 
-B<database>
- The name of your Drupal database. Required.
+=over 4
 
-B<driver>
- The DBI driver for your database. Required, from [mysql|Pg|SQLite].
+=item *
 
-B<username>
- The database username. Optional. Must be a string if supplied.
+database
 
-B<password>
- The database password. Optional. Must be a string if supplied.
+The name of your Drupal database. Required.
 
-B<host>
- The server where the DB lives. Optional. Must be a string if supplied.
+=item *
 
-B<port>
- The port on which to connect. Optional. Must be an integer if supplied.
+driver
 
-B<prefix>
- The prefix that you set in Drupal for your DB table names (if any).
- Optional. Must be at least two characters and end with a "_").
+The DBI driver for your database. Required, from [mysql|Pg|SQLite].
+
+=item *
+
+username
+
+The database username. Optional. Must be a string if supplied.
+
+=item *
+
+password
+
+The database password. Optional. Must be a string if supplied.
+
+=item *
+
+host
+
+The server where the DB lives. Optional. Must be a string if supplied.
+
+=item *
+
+port 
+
+port on which to connect. Optional. Must be an integer if supplied.
+
+=item *
+
+prefix
+
+The prefix that you set in Drupal for your DB table names (if any). Optional. Must be at least two characters and end with a "_").
+
+=back
 
 =head3 Testing
 
-The following is taken from t/Drupal02.t and explains how to have this 
+The following is taken from t/20_valid_drupal.t and explains how to have this 
 module test against your actual Drupal installation.
 
+B<Quote>
+
 =over 4
 
- B<Quote>
- This is t/Drupal02.t It tests the CMS::Drupal module against a real Drupal
+ This is t/20_valid_drupal.t It tests the CMS::Drupal module against a real Drupal
  database. It looks in your environment to see if you have provided
  connection information.
 
@@ -178,26 +196,39 @@ module test against your actual Drupal installation.
  If you just want to run this test once, you can just do this from your
  command prompt:
 
- $ DRUPAL_TEST_CREDS=database,foo,driver,SQLite; perl ./Drupal_02.t
-
- B<End Quote>
+ $ DRUPAL_TEST_CREDS=database,foo,driver,SQLite
+ $ perl t/20_valid_drupal.t
 
 =back
 
-=head1 AUTHOR
- 
-Author: Nick Tonkin (tonkin@cpan.org)
+B<End Quote>
+
+=head1 FUNCTIONALITY
+
+As of this writing, all the author needs is a DB handle in order to use other
+CMS::Drupal::* modules. You are welcome to contribute code if you want this
+module to do anything else. For example, many CMS interfaces allow you to put
+the CMS into "maintenance mode," so you can work on the database with the
+site off-line. It would be relatively simple to add methods for tasks such as
+that.
+
+=head1 USAGE
+
+Use the module as shown in the Synopsis above.
 
-=head1 COPYRIGHT
- 
-Copyright (c) 2015 Nick Tonkin. All rights reserved.
- 
-=head1 LICENSE
- 
-You may distribute this module under the same license as Perl itself.
- 
 =head1 SEE ALSO
 
 L<CMS::Drupal::Types|CMS::Drupal::Types>
 
+=head1 AUTHOR
+
+Nick Tonkin <tonkin@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Nick Tonkin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
