@@ -1,5 +1,5 @@
 package CMS::Drupal::Admin;
-$CMS::Drupal::Admin::VERSION = '0.093';
+$CMS::Drupal::Admin::VERSION = '0.094';
 # ABSTRACT: Provides the namespace for CMS::Drupal::Admin::* packages.
 
 use strict;
@@ -12,13 +12,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-CMS::Drupal::Admin
+CMS::Drupal::Admin - Provides the namespace for CMS::Drupal::Admin::* packages.
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -31,3 +33,16 @@ CMS::Drupal::Admin::* packages.
 
 Authors wishing to contribute packages for interacting administratively
 with a Drupal installation should create them under this namespace.
+
+=head1 AUTHOR
+
+Nick Tonkin <tonkin@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Nick Tonkin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
