@@ -1,9 +1,8 @@
 package CMS::Drupal::Admin::MaintenanceMode;
-$CMS::Drupal::Admin::MaintenanceMode::VERSION = '0.093';
+$CMS::Drupal::Admin::MaintenanceMode::VERSION = '0.094';
 # ABSTRACT: Put your Drupal site into Maintenance Mode, or take it out
 
 use strict;
-use 5.010;
 
 use base "Exporter::Tiny";
 our @EXPORT = qw/ maintenance_mode_check
@@ -73,15 +72,19 @@ sub maintenance_mode_off {
 
 1; # return true
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-CMS::Drupal::Admin::MaintenanceMode
+CMS::Drupal::Admin::MaintenanceMode - Put your Drupal site into Maintenance Mode, or take it out
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -108,32 +111,39 @@ Note that this and all CMS::Drupal::* Perl packages interact with
 the database directly, not with the website. You must have the 
 user credentials for your database in order to use these tools.
 
-=head1 USAGE
+=head1 METHODS
 
-Use the module as shown in the SYNOPSIS.
-
-=head2 METHODS
-
-=over 4
-
-=item maintenance_mode_check
+=head2 maintenance_mode_check
 
 Returns 1 if the site is currently in maintenance mode, otherwise
 returns 0. Take one argument; your active $dbh.
 
-=item maintenance_mode_on
+=head2 maintenance_mode_on
 
 Puts the site into maintenance mode. Returns 1 if there was no failure;
 i.e. the site was successfully put into, or already was in, maintenance
 mode. Returns 0 on DB error. Takes one argument; your active $dbh.
 
-=item maintenance_mode_off
+=head2 maintenance_mode_off
 
 Takes the site out of maintenance mode. Returns 1 if there was no 
 failure; i.e. the site was successfully taken out of, or was already
 not in, maintenance mode. Returns 0 on DB error. Takes one argument;
 your active $dbh.
 
-=back
+=head1 USAGE
+
+Use the module as shown in the SYNOPSIS.
+
+=head1 AUTHOR
+
+Nick Tonkin <tonkin@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Nick Tonkin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
