@@ -1,10 +1,9 @@
 package CMS::Drupal::Types;
-$CMS::Drupal::Types::VERSION = '0.093';
+$CMS::Drupal::Types::VERSION = '0.094';
 # ABSTRACT: A Perl type library for working with Drupal
 
 use strict;
 use warnings;
-use 5.010;
 
 use Type::Library -base, -declare => qw/ DBName
                                          DBDriver
@@ -38,17 +37,20 @@ declare DBPrefix, as Optional[StrMatch[ qr/ \w+_ /x ]],
   message { return 'The table prefix must end in an underscore. ' };
 
 1; ## return true to end package CMS::Drupal::Types
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CMS::Drupal::Types - A Perl type library for working with Drupal
 
 =head1 VERSION
 
-version 0.093
+version 0.094
 
 =head1 SYNOPSIS
 
@@ -70,16 +72,16 @@ If you want to use the types to validate parameters passed to a method or a sub,
   sub my_sub {
     my $args = { @_ };
     my %types = (
-      database => DBName,
-      driver   => DBDriver,
-      username => DBUsername,
-      password => DBPassword,
+      'database' => DBName,
+      'driver'   => DBDriver,
+      'username' => DBUsername,
+      'password' => DBPassword,
     );
    
     for( keys %$args ) {
       my $validate = compile( slurpy Dict [ $_ => $types{$_} ]);
       my ($param) = $validate->( $_ => $args->{$_} );
-      say "$_: '$args->{$_}' passed";
+      print "$_: '$args->{$_}' passed";
     }
   }
 
@@ -106,29 +108,41 @@ B<DBPort>
 B<DBPrefix>
  Must be a string ending in an underscore if present. May be omitted.
 
-
-=head1 AUTHOR
- 
-Author: Nick Tonkin (tonkin@cpan.org)
-
-=head1 COPYRIGHT
- 
-Copyright (c) 2015 Nick Tonkin. All rights reserved.
- 
-=head1 LICENSE
- 
-You may distribute this module under the same license as Perl itself.
- 
 =head1 SEE ALSO
 
-L<CMS::Drupal|CMS::Drupal>.
+=over 4
+
+=item *
+
+L<CMS::Drupal|CMS::Drupal>
+
+=item *
 
 L<Type::Tiny|Type::Tiny>
 
+=item *
+
 L<Type::Library|Type::Library>
 
+=item *
+
 L<Types::Standard|Types::Standard>
 
+=item *
+
 L<Type::Params|Type::Params>
 
+=back
+
+=head1 AUTHOR
+
+Nick Tonkin <tonkin@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Nick Tonkin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
